@@ -168,6 +168,9 @@ sub get_addr_entry {
 sub add_score {
     my($self, $entry, $score) = @_;
 
+    $entry->{count} ||= 0;
+    $entry->{addr}  ||= '';
+
     $entry->{count}++;
     $entry->{totscore} += $score;
 
