@@ -399,7 +399,11 @@ sub razor2_lookup {
           $response = 0;
         }
         else {
-          $rc->connect() or die $rc->errprefix("checkit");
+          if (!$rc->connect()) {
+            # provide a better error message when servers are unavailable,
+            # than "Bad file descriptor Died".
+            die "could not connect to any servers\n";
+          }
           $rc->check($objects) or die $rc->errprefix("checkit");
           $rc->disconnect() or die $rc->errprefix("checkit");
           $response = $objects->[0]->{spam};
@@ -444,7 +448,6 @@ sub razor2_lookup {
 
 sub is_dcc_available {
   my ($self) = @_;
-  my (@resp);
 
   if ($self->{main}->{local_tests_only}) {
     dbg ("local tests only, ignoring DCC");
@@ -467,7 +470,7 @@ sub is_dcc_available {
     return 0;
   }
 
-  dbg ("DCC is available: ".join(" ", @resp));
+  dbg ("DCC is available: ".$self->{conf}->{dcc_path});
   return 1;
 }
 
@@ -571,7 +574,6 @@ sub dcc_lookup {
 
 sub is_pyzor_available {
   my ($self) = @_;
-  my (@resp);
 
   if ($self->{main}->{local_tests_only}) {
     dbg ("local tests only, ignoring Pyzor");
@@ -594,7 +596,7 @@ sub is_pyzor_available {
     return 0;
   }
 
-  dbg ("Pyzor is available: ".join(" ", @resp));
+  dbg ("Pyzor is available: ".$self->{conf}->{pyzor_path});
   return 1;
 }
 
